Renamed FLAG_ACTIVITY_LAUNCH_TO_SIDE to FLAG_ACTIVITY_LAUNCH_ADJACENT

Per feedback from API council.

Bug: 26508215
Change-Id: Id17166fe981587c9c16c382ccbdf0846ed2ae5d6
diff --git a/core/java/android/content/Intent.java b/core/java/android/content/Intent.java
index ee469da..debfa89 100644
--- a/core/java/android/content/Intent.java
+++ b/core/java/android/content/Intent.java
@@ -4587,11 +4587,11 @@
     public static final int FLAG_ACTIVITY_RETAIN_IN_RECENTS = 0x00002000;
 
     /**
      * This flag is only used in the multi-window mode. The new activity will be displayed on
      * the other side than the one that is launching it. This can only be used in conjunction with
      * {@link #FLAG_ACTIVITY_NEW_TASK}.
      */
-    public static final int FLAG_ACTIVITY_LAUNCH_TO_SIDE = 0x00001000;
+    public static final int FLAG_ACTIVITY_LAUNCH_ADJACENT = 0x00001000;
 
     /**
      * If set, when sending a broadcast only registered receivers will be
@@ -4587,11 +4587,11 @@
 
     /**
-     * This flag is only used in the multi-window mode. The new activity will be displayed on
-     * the other side than the one that is launching it. This can only be used in conjunction with
+     * This flag is only used in split-screen multi-window mode. The new activity will be displayed
+     * adjacent to the one launching it. This can only be used in conjunction with
      * {@link #FLAG_ACTIVITY_NEW_TASK}.
      */